@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -248,34 +248,6 @@ iEventObserver* iShellFactory::CreateEventObserver(const iString &type, iViewMod
 		}
 	}
 
-	if(type == "Record") 
-	{
-		if(shell->Type() == qt)
-		{
-#if ISHELL_INCLUDED(ISHELL_QT)
-			return new iggRecordEventObserver(vm);
-#else
-			return 0;
-#endif
-		}
-		if(shell->Type() == cl)
-		{
-#if ISHELL_INCLUDED(ISHELL_CL)
-			return new iclRecordEventObserver(vm);
-#else
-			return 0;
-#endif
-		}
-		if(shell->Type() == fx)
-		{
-#if ISHELL_INCLUDED(ISHELL_FX)
-			return new iggRecordEventObserver(vm);
-#else
-			return 0;
-#endif
-		}
-	}
-
 	if(type == "Animator") 
 	{
 		if(shell->Type() == qt)
