@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -40,14 +40,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-iCommandInterpreter::iCommandInterpreter(iShell *s) : mShell(s)
+iCommandInterpreter::iCommandInterpreter(iShell *s) : mShell(s), mErrorStatus("Command Interpreter")
 {
-	mBreakFlag = mExecFlag = mWorkFlag = false;
 	mReturnState = 0;
-
-#ifdef I_DEBUG
-	mKeepVars = true;
-#endif
+	mExecuted = false;
 }
 
 
@@ -66,167 +62,143 @@ void iCommandInterpreter::Start()
 }
 
 
-int iCommandInterpreter::Exec()
+void iCommandInterpreter::Stop()
 {
-	iString line;
+	this->Finalize();
+}
 
-	mScriptText.Clear();
-	mBreakFlag = false;
-	mReturnState = 0;
 
-	while(!mBreakFlag)
+void iCommandInterpreter::Append(const iString &text, char exec_char)
+{
+	int i, n;
+	bool exec = false;
+	iString input, output, line;
+	
+	mExecuted = false;
+
+	input = text;
+	if(exec_char != 0)
 	{
-		this->DisplayPrompt();
-
-		//
-		//  Read in single line from "stdin"
-		//
-		line.Clear();
-		this->ReadLineOfText(line);
-
-		this->ExecLineBody(line);
+		int io = input.Length() - 1;
+		while(io>=0 && input.IsWhiteSpace(io)) io--;
+		if(io>=0 && input[io]==exec_char)
+		{
+			//
+			//  Remove the semi-colon
+			//
+			input.Replace(io,' ');
+			exec = true;
+		}
 	}
 
-	return mReturnState;
-}
-
-
-void iCommandInterpreter::ExecLine(iString &line)
-{
 	//
-	//  Reset the flags
+	//  Clear the error status
 	//
-	mBreakFlag = false;
 	mReturnState = 0;
+	this->GetErrorStatus()->Clear();
 
-	this->ExecLineBody(line);
+	n = input.Contains('\n');
+	for(i=0; i<n; i++)
+	{
+		line = input.Section("\n",i,i);
+		line.ReduceWhiteSpace();
+
+		//
+		//  Shell-specific commands
+		//
+		this->AnalyseSpecialCommands(line);
+
+		//
+		//  Redirection sign reads from an external file
+		//
+		if(!line.IsEmpty() && line[0]=='<')
+		{
+			iString s = line.Part(1);
+			s.ReduceWhiteSpace();
+			iDirectory::ExpandFileName(s,this->GetShell()->GetEnvironment(Environment::Base));
+
+			iFile F(s);
+			if(F.Open(iFile::_Read,iFile::_Text))
+			{
+				iString s;
+				while(F.ReadLine(s)) if(!s.IsEmpty())
+				{
+					this->DislayLineOfText("==> "+s,CommandInterpreterType::Code);
+					output += s + "\n";
+				}
+				F.Close();
+			}
+			else
+			{
+				this->DislayLineOfText("File does not exist.",CommandInterpreterType::Error);
+				mReturnState = -1;
+				return;
+			}
+			line.Clear();
+		}
+
+		//
+		//  Help, print, and list are executed at once
+		//
+		if(this->IsHelpRequest(line))
+		{
+			this->RunScript(line);
+			if(!this->GetErrorStatus()->Message().IsEmpty())
+			{
+				this->DislayLineOfText("ERROR: "+this->GetErrorStatus()->Message(),CommandInterpreterType::Error);
+				mReturnState = -1;
+				return;
+			}
+			line.Clear();
+		}
+
+		//
+		// Form a script
+		//
+		if(!line.IsEmpty()) output += line + "\n";
+	}
+
+	mBufferedScript += output;
+
+	if(exec) this->Exec();
 }
 
 
-void iCommandInterpreter::ExecLineBody(const iString &line0)
+void iCommandInterpreter::Exec()
 {
 	//
 	//  Clear the error status
 	//
-	this->Script()->GetErrorStatus()->Clear();
-
-	iString line(line0);
+	mReturnState = 0;
+	this->GetErrorStatus()->Clear();
 
 	//
-	//  Is this an exec line?
+	//  Execute the script
 	//
-	mExecFlag = false;
-	mWorkFlag = false;
-	iString w(line);
-	w.ReduceWhiteSpace();
-	if(w.EndsWith(";"))
+	this->RunScript(mBufferedScript);
+
+	if(this->GetErrorStatus()->NoError())
 	{
-		mExecFlag = true;
-		//
-		//  Remove the semi-colon
-		//
-		line.Replace(";","");
+		mExecutedScript += mBufferedScript;
+		mLastExecutedScriptPiece = mBufferedScript;
 	}
-
-	//
-	//  Shell-specific commands
-	//
-	this->AnalyseSpecialCommands(line);
-	if(mBreakFlag)
-	{
-		mExecFlag = false;
-		return;
-	}
-
-	//
-	//  Redirection sign reads from an external file
-	//
-	if(!line.IsEmpty() && line[0]=='<')
-	{
-		iString s = line.Part(1);
-		s.ReduceWhiteSpace();
-		iDirectory::ExpandFileName(s,this->GetShell()->GetEnvironment(Environment::Base));
-
-		iFile F(s);
-		if(F.Open(iFile::_Read,iFile::_Text))
-		{
-			iString s;
-			while(F.ReadLine(s)) if(!s.IsEmpty())
-			{
-				this->DislayLineOfText("==> "+s,CommandInterpreterType::Code);
-				if(s[s.Length()-1] == ';')
-				{
-					mExecFlag = true;
-					//
-					//  Remove the semi-colon
-					//
-					s = s.Part(0,s.Length()-1);
-				}
-				mScriptText += s + "\n";
-			}
-			F.Close();
-		}
-		else
-		{
-			this->DislayLineOfText("File does not exist.",CommandInterpreterType::Error);
-		}
-		line.Clear();
-	}
-
-	//
-	//  Help, print, and list are executed at once
-	//
-	if(this->IsHelpRequest(line))
-	{
-		mExecFlag = false;
-		mWorkFlag = true;
-		this->Script()->SetText(line);
-		this->Script()->Execute(true); // do not reset the script!!!
-		if(!this->Script()->GetErrorStatus()->Message().IsEmpty())
-		{
-			this->DislayLineOfText("ERROR: "+this->Script()->GetErrorStatus()->Message(),CommandInterpreterType::Error);
-		}
-		return;
-	}
-
-	//
-	// Form a script
-	//
-	mScriptText += line + "\n";
-	if(mExecFlag)
-	{
-		//
-		//  Execute the script - must mutex it since it is called from a thread
-		//
-		mWorkFlag = true;
-		this->Script()->SetText(mScriptText);
-#ifdef I_DEBUG
-		this->Script()->Execute(mKeepVars);
-#else
-		this->Script()->Execute(true); // do not reset the script!!!
-#endif
-		mLastExecutedScriptText = mScriptText;
-		mScriptText.Clear();
-		if(this->Script()->GetErrorStatus()->IsError())
-		{
-			this->DislayLineOfText("ERROR: "+this->Script()->GetErrorStatus()->Message(),CommandInterpreterType::Error);
-		}
-	}
-
-	this->CheckBreak();
+	mBufferedScript.Clear();
+	mExecuted = true;
 }
 
 
-void iCommandInterpreter::Break(int ret)
+void iCommandInterpreter::RunScript(const iString &text, bool reset)
 {
-	mReturnState = ret;
-	mBreakFlag = true;
-}
+	this->GetErrorStatus()->Monitor(this->Script()->GetErrorStatus());
 
+	this->Script()->SetText(text);
+	this->Script()->Execute(!reset); // do not reset the script!!!
 
-void iCommandInterpreter::Stop()
-{
-	this->Finalize();
+	if(this->GetErrorStatus()->IsError())
+	{
+		this->DislayLineOfText("ERROR: "+this->GetErrorStatus()->Message(),CommandInterpreterType::Error);
+		mReturnState = -1;
+	}
 }
 
 
