@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -42,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkSetGet.h>
 
 class iControlScript;
+class iErrorStatus;
 class iShell;
 
 
@@ -63,22 +64,25 @@ class iCommandInterpreter : public vtkObjectBase
 {
 
 	IPOINTER_AS_PART(Shell);
+	IPOINTER_AS_USER(ErrorStatus);
 
 public:
 
 	vtkTypeMacro(iCommandInterpreter,vtkObjectBase);
 
 	void Start();
-	int Exec();
-	void ExecLine(iString &line);
-	void Break(int ret);
 	void Stop();
 
+	void Append(const iString &text, char exec_char = ';');
+	void Exec();
+
 	virtual void DislayLineOfText(const iString &text, int type) const = 0;
 
-	inline bool GetExecFlag() const { return mExecFlag; }
-	inline bool GetWorkFlag() const { return mWorkFlag; }
-	inline const iString& GetLastExecutedScriptText() const { return mLastExecutedScriptText; }
+	inline bool IsExecuted() const { return mExecuted; }
+	inline int GetReturnState() const { return mReturnState; }
+	inline const iString& GetExecutedScript() const { return mExecutedScript; }
+	inline const iString& GetLastExecutedScriptPiece() const { return mLastExecutedScriptPiece; }
+
 	virtual iControlScript* Script() const; // just in case... (to allow script substitutions)
 
 protected:
@@ -86,29 +90,21 @@ protected:
 	iCommandInterpreter(iShell *s);
 	virtual ~iCommandInterpreter();
 
-	void ExecLineBody(const iString &line);
-
 	virtual bool IsHelpRequest(const iString &line) const;
+	virtual void RunScript(const iString &text, bool reset = false);
 
 	virtual void Initialize() = 0;
-	virtual void DisplayPrompt() const = 0;
-	virtual void ReadLineOfText(iString &line) const = 0;
 	virtual void AnalyseSpecialCommands(const iString &line) = 0;
-	virtual void CheckBreak() = 0;
 	virtual void Finalize() = 0;
 
-#ifdef I_DEBUG
-	bool mKeepVars;
-#endif
-
 private:
 
 	//
 	//  Private, to make sure they are not changed accidentally
 	//
-	bool mBreakFlag, mExecFlag, mWorkFlag;
+	bool mExecuted;
 	int mReturnState;
-	iString mScriptText, mLastExecutedScriptText;
+	iString mBufferedScript, mExecutedScript, mLastExecutedScriptPiece;
 };
 
 #endif  // ICOMMANDINTERPRETER_H
