@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -349,27 +349,6 @@ void iPickEventObserver::ExecuteBody(vtkObject *caller, unsigned long eventId, v
 }
 
 
-//
-//  iRecordEventObserver class
-//
-iRecordEventObserver* iRecordEventObserver::New(iViewModule *vm)
-{
-	IERROR_ASSERT(vm);
-	return iRequiredCast<iRecordEventObserver>(INFO,iShellFactory::CreateEventObserver("Record",vm));
-}
-
-
-iRecordEventObserver::iRecordEventObserver(iViewModule *vm) : iEventObserver(vm->GetControlModule()->GetShell()), mViewModule(vm)
-{
-}
-
-
-void iRecordEventObserver::ExecuteBody(vtkObject *, unsigned long eventId, void *)
-{
-	if(eventId == vtkCommand::InteractionEvent) this->UpdateInteraction(); 
-}
-
-
 //
 //  iParallelUpdateEventObserver class
 //
