@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -189,26 +189,6 @@ protected:
 };
 
 
-class iRecordEventObserver : public iEventObserver
-{
-	
-	IPOINTER_AS_PART(ViewModule);
-
-public:
-	
-	vtkTypeMacro(iRecordEventObserver,iEventObserver);
-	static iRecordEventObserver* New(iViewModule *vm = 0);
-
-	virtual void UpdateInteraction() = 0;
-
-protected:
-
-	iRecordEventObserver(iViewModule *vm);
-
-	virtual void ExecuteBody(vtkObject *caller, unsigned long event, void *data);
-};
-
-
 class iParallelUpdateEventObserver : public iEventObserver
 {
 	
