@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -230,7 +230,17 @@ namespace iControlScript_Private
 	//
 	bool SaveState(iScript *self, const iString &arg)
 	{
-		if(!curControl->SaveStateToFile(arg))
+		iString filename(arg);
+		if(filename.IsEmpty())
+		{
+			filename = curControl->GetShell()->GetEnvironment(Environment::Base) + "ifrit.ini";
+		}
+		else if(filename[0] == '+')
+		{
+			filename.Replace(0,1,curControl->GetShell()->GetEnvironment(Environment::Base));
+		}
+
+		if(!curControl->SaveStateToFile(filename))
 		{
 			self->GetErrorStatus()->Set("Saving state to a file failed.");
 			return false;
@@ -241,7 +251,17 @@ namespace iControlScript_Private
 
 	bool LoadState(iScript *self, const iString &arg)
 	{
-		if(!curControl->LoadStateFromFile(arg))
+		iString filename(arg);
+		if(filename.IsEmpty())
+		{
+			filename = curControl->GetShell()->GetEnvironment(Environment::Base) + "ifrit.ini";
+		}
+		else if(filename[0] == '+')
+		{
+			filename.Replace(0,1,curControl->GetShell()->GetEnvironment(Environment::Base));
+		}
+
+		if(!curControl->LoadStateFromFile(filename))
 		{
 			self->GetErrorStatus()->Set("Loading state from a file failed.");
 			return false;
@@ -335,7 +355,7 @@ iControlScript::iControlScript(iControlModule *cm, iScript *parent) : iBasicScri
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("hide",Hide);
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("print",Print);  // prints anything
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("create",Create);
-	this->AddPrototype< iScriptKit::FunctionCallStatement >("remove",Remove);
+	this->AddPrototype< iScriptKit::FunctionCallStatement >("delete",Remove);
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("animate",Animate);
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("exec-all-objects",ExecAllObjects);
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("exec-all-windows",ExecAllWindows);
