@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -153,13 +153,13 @@ void iCrossSectionPipeline::SetTextureOffset(vtkImageData *input)
 			//
 			//  Split along Axis
 			//
-			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),0,0);
+			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),0,0,globalOrg,globalDims);
 		}
 		else
 		{
 			int offx = round((org[Uidx]-globalOrg[Uidx])/spa[Uidx]);
 			int offy = round((org[Vidx]-globalOrg[Vidx])/spa[Vidx]);
-			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),offx,offy);
+			mTextureConverter->SetTexturePiece(mParent->GetTextureData(),offx,offy,globalOrg,globalDims);
 		}
 	}
 }
