@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -377,7 +377,7 @@ void iCrossSectionViewSubject::PlaceAtSpecialLocation(int n)
 				{
 					de->SetActiveDataType(this->GetDataType());
 					de->SetInputComponent(this->GetVar());
-					const iDataExplorer::Info &di = de->GetInfo(true);
+					const iDataExplorer::Info &di = de->GetInfo(true,0);
 					if(n == 0)
 					{
 						if(di.CellMin >= 0) this->SetPosition(*di.PosMin);
