@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -188,8 +188,13 @@ bool iHistogramMaker::ComputeRange()
 	//
 	//  Do we need to recompute?
 	//
-	if(this->GetInput()->GetMTime() > mComputeTime) 
+	if(this->GetInput()->GetMTime()>mComputeRangeTime || this->GetMTime()>mComputeRangeTime)
 	{
+		//
+		//  Must recompute
+		//
+		mComputeRangeTime.Modified();
+
 		//	
 		//  Recompute the limits
 		//
