@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -118,7 +118,7 @@ private:
 	//  MTime for the last calculation of the histogram - need to keep track of it
 	//  separately so that other changes to this class do not hide the change in the input data.
 	//
-	vtkTimeStamp mComputeTime;
+	vtkTimeStamp mComputeTime, mComputeRangeTime;
 
 	//
 	//  Persisting helper variables
