@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -175,7 +175,9 @@ void iOrthoSlicer::ProduceOutput()
 	//
 	int ijk[3], ijk1[3], ijk2[3];
     float ht = (mPos[mDir]-orgIn[mDir])/spaIn[mDir];	//Normalized height
+	if(input->GetVoxelLocation() == VoxelLocation::Center) ht -= 0.5;
     ijk[mDir] = int(ht);								//Grid Point below
+	if(ht < ijk[mDir]) ijk[mDir]--;
     float ss1, ss2 = (ht-ijk[mDir]);					//interpolation factor
 
 	//
