@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -214,10 +214,23 @@ namespace iParticleGroup_Private
 	class ArtifactCorrector : public iArtifactCorrector
 	{
 
-		IGENERICFILTER_DECLARE(ArtifactCorrector,iArtifactCorrector);
+	public:
+
+		vtkTypeMacro(ArtifactCorrector,iArtifactCorrector);
+
+		static ArtifactCorrector* New(iParticleGroup *vo = 0)
+		{
+			IERROR_ASSERT(vo);
+			return new ArtifactCorrector(vo);
+		}
 
 	protected:
 
+		ArtifactCorrector(iParticleGroup *vo) : iArtifactCorrector(vo)
+		{
+			mOwner = vo;
+		}
+
 		virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop)
 		{
 			//
@@ -225,16 +238,14 @@ namespace iParticleGroup_Private
 			//
 			if(prop!=0 && ren->GetRenderWindow()!=0)
 			{
-				return (prop->GetOpacity()==1.0 && ren->GetRenderWindow()->GetPointSmoothing()!=0);
+				return (prop->GetOpacity()==1.0 && ren->GetRenderWindow()->GetPointSmoothing()!=0) || mOwner->GetAttributeToColor()>-1;
 			}
 			else return false;
 		}
-	};
 
-	ArtifactCorrector::ArtifactCorrector(iViewSubject *vo) : iArtifactCorrector(vo)
-	{
-	}
-}
+		iParticleGroup *mOwner;
+	};
+};
 
 
 using namespace iParticleGroup_Private;
