@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -281,12 +281,12 @@ bool iParticleSplitter::DeleteGroup(int n)
 {
 	if(mRanges->RemoveRange(n))
 	{
-		this->RemoveOutput(Outputs[n]);
 		int i;
 		for(i=n; i<mRanges->GetN(); i++)
 		{
 			this->SetNthOutput(i,this->GetOutput(i+1));
 		}
+		this->SetNumberOfOutputs(mRanges->GetN());
 		return true;
 	}
 	else return false;
