@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -701,7 +701,7 @@ int iParticlesViewSubject::CreateGroup()
 	int newGroup = mGroups->CreateMember();
 	if(newGroup == -1)
 	{
-		mSplitter->DeleteGroup(mSplitter->GetNumberOfOutputs());
+		mSplitter->DeleteGroup(mSplitter->GetNumberOfOutputs()-1);
 		return -1;
 	}
 
@@ -725,7 +725,16 @@ bool iParticlesViewSubject::DeleteGroup(int n)
 	if(mSplitter->DeleteGroup(n))
 	{
 		this->ClearCache();
-		return mGroups->DeleteMember(n);
+		if(mGroups->DeleteMember(n))
+		{
+			//
+			//  Need to update inputs
+			//
+			int i;
+			for(i=n; i<=mGroups->GetMaxMemberIndex(); i++) mGroups->GetMember(i)->SetInput(mSplitter->GetOutput(i));
+			return true;
+		}
+		else return false;
 	}
 	else return false;
 }
