@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -857,7 +857,7 @@ void iRenderTool::SetStereoMode(int m)
 			if(mMainWin->GetStereoCapableWindow() == 0)
 			{
 				this->SetStereoMode(0);
-				iConsole::Display(iConsole::_Notification,"Crustal Eyes mode is not supported on this machine.");
+				iConsole::Display(iConsole::_Notification,"Crystal Eyes mode is not supported on this machine.");
 			}
 			else
 			{
