@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -129,7 +129,8 @@ void iSmoothPolyDataFilter::ProduceOutput()
 	numCells=input->GetNumberOfCells();
 	if (numPts < 1 || numCells < 1)
 	{
-		vtkErrorMacro(<<"No data to smooth!");
+	/// ------ Removed ------------------------------------------
+	///	vtkErrorMacro(<<"No data to smooth!");
 		return;
 	}
 
