@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -52,7 +52,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iextensionfactory.h"
 #include "ifile.h"
 #include "iimagecomposer.h"
-#include "iinteractoreventrecorder.h"
 #include "ikeyboardinteractorstyle.h"
 #include "ilightkit.h"
 #include "imarker.h"
@@ -253,7 +252,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mInImageRender = false;
 	mBackgroundImageFixedAspect = false;
 
-	mRate = 0;
+	mRate = 10;
 	mBoxSize = -1.0;
 	mCloneOfModule = 0;
 	mWinNum = 0;
@@ -425,17 +424,6 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mPicker = iPicker::New(this); IERROR_ASSERT(mPicker);
 	mRenderTool->GetInteractor()->SetPicker(mPicker->GetHandler());
 
-	//
-	//  Event recorder
-	//  
-	mEventRecorder = iInteractorEventRecorder::New(); IERROR_ASSERT(mEventRecorder);
-	mEventRecorder->SetInteractor(mRenderTool->GetInteractor());
-	mEventRecorder->SetEnabled(1);
-
-	mObsRecord = iRecordEventObserver::New(this); IERROR_ASSERT(mObsRecord);
-
-	for(i=0; i<InteractorStyle::SIZE; i++) mInteractorStyle[i]->AddObserver(vtkCommand::InteractionEvent,mObsRecord);
-
 	//
 	//  Must be created before marker family
 	//
@@ -537,9 +525,6 @@ iViewModule::~iViewModule()
 	mRenderTool->RemoveObject(mColorBars->GetActor(false));
 	mColorBars->Delete();
 
-	mEventRecorder->SetInteractor(0);
-	mEventRecorder->Delete();
-	mObsRecord->Delete();
 	mInteractorStyleCaption->Delete();
 
 	mUpdateTimer->Delete();
@@ -1458,7 +1443,7 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	//
 	if(this->UnPackValue(s,KeyCloneOfWindow(),i)) if(i >= 0) BecomeClone(this->GetControlModule()->GetViewModule(i));
 
-//	if(this->UnPackValue(s,KeyPosition(),iv,2)) win->SetPosition(iv);
+	//if(this->UnPackValue(s,KeyPosition(),iv,2)) mRenderTool->SetRenderWindowPosition(iv);
 	iv[0] = mRenderTool->GetRenderWindowSize()[0];
 	iv[1] = mRenderTool->GetRenderWindowSize()[1];
 	if(this->UnPackValue(s,KeySize(),iv,2))
