@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -54,7 +54,6 @@ class iDataConsumer;
 class iDataReader;
 class iDataSyncRequest;
 class iDataType;
-class iInteractorEventRecorder;
 class iMarker;
 class iMarkerFamily;
 class iMeasuringBox;
@@ -62,7 +61,6 @@ class iParallelManager;
 class iParticlesViewSubject;
 class iPicker;
 class iProgressEventObserver;
-class iRecordEventObserver;
 class iRenderTool;
 class iRuler;
 class iSlaveAbortRenderEventObserver;
@@ -272,7 +270,6 @@ public:
 	vtkRenderWindowCollection* GetRenderWindowCollection(bool inited = false) const;
 
 	inline iProgressEventObserver* GetProgressEventObserver() const { return mObsProgress; }
-	inline iRecordEventObserver* GetRecordEventObserver() const { return mObsRecord; }
 	inline iAbortRenderEventObserver* GetAbortRenderEventObserver() const { return mObsAbortRender; }
 	inline iSlaveAbortRenderEventObserver* GetSlaveAbortRenderEventObserver() const { return mObsSlaveAbortRender; }
 	inline iPicker* GetPicker() const { return mPicker; }
@@ -285,8 +282,6 @@ public:
 	inline iDataReader* GetReader() const { return mDataReader; }
 	iParallelManager* GetParallelManager() const;
 	
-	inline iInteractorEventRecorder* GetEventRecorder() const { return mEventRecorder; }
-
 	void RenderStereoImage(iStereoImage &image);
 	void CreateImages(iStereoImageArray &images);
 	void RenderImages(iStereoImageArray &images);
@@ -410,7 +405,6 @@ private:
 	//
 	iAnimator *mAnimator;
 	iDataReader *mDataReader;
-	iInteractorEventRecorder *mEventRecorder;
 	iPicker *mPicker;
 	iPointerArray<iDataConsumer> mDataConsumers;
 	iCubeAxesActor *mBox3AxesLabels;
@@ -428,7 +422,6 @@ private:
 	iProgressEventObserver *mObsProgress;
 	iAbortRenderEventObserver *mObsAbortRender;
 	iSlaveAbortRenderEventObserver *mObsSlaveAbortRender;
-	iRecordEventObserver *mObsRecord;
 
 	//
 	//  iViewSubject-related members
