@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -49,10 +49,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 #include "iviewsubjectobserver.h"
 #include "ivolumedataconverter.h"
+#include "ivtk.h"
 
 #include <vtkToolkits.h>
 
 #include <vtkFixedPointVolumeRayCastMapper.h> 
+#ifndef IVTK_PRE56
+#include <vtkGPUVolumeRayCastMapper.h>
+#endif
 #include <vtkStructuredPoints.h>
 #include <vtkVolumeProperty.h>
 #include <vtkVolumeRayCastCompositeFunction.h>
@@ -125,6 +129,11 @@ namespace iVolumeViewSubject_Private
 		{
 			return (ds!=0 && ds->IsA("vtkImageData")!=0);
 		}
+
+		virtual bool IsAvailable()
+		{
+			return true;
+		}
 	};
 
 
@@ -250,7 +259,16 @@ namespace iVolumeViewSubject_Private
 		virtual bool IsUsingData(vtkDataSet *ds)
 		{
 			if(!this->UniformGridVolumeRenderingHelper::IsUsingData(ds)) return false;
+			return this->IsAvailable();
+		}
+
+		virtual bool IsAvailable()
+		{
+#ifdef IVTK_PRE561
 			return (mMapper->IsRenderSupported(mParent->GetVolume()->GetProperty()) != 0);
+#else
+			return (mMapper->IsRenderSupported(mParent->GetVolume()->GetProperty(),mParent->GetViewModule()->GetRenderer()) != 0);
+#endif
 		}
 
 		virtual vtkAbstractVolumeMapper* GetMapper()
@@ -322,6 +340,67 @@ namespace iVolumeViewSubject_Private
 		vtkFixedPointVolumeRayCastMapper *mMapper;
 	};
 
+
+#ifndef IVTK_PRE56
+	class GPURayCastHelper  : public UniformGridVolumeRenderingHelper
+	{
+
+	public:
+
+		GPURayCastHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"GPU ray casting")
+		{
+			mMapper = vtkGPUVolumeRayCastMapper::New(); IERROR_ASSERT(mMapper);
+			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
+			//mMapper->IntermixIntersectingGeometryOn();
+			mMapper->AutoAdjustSampleDistancesOn();
+			mMapper->SetInput(input);
+			mMapper->SetBlendModeToComposite();
+		}
+
+		virtual ~GPURayCastHelper()
+		{
+			mMapper->Delete();
+		}
+
+		virtual vtkAbstractVolumeMapper* GetMapper()
+		{
+			return mMapper;
+		}
+
+		virtual void SetBlendMode(int m)
+		{
+			mMapper->SetBlendMode(m);
+		}
+
+		virtual bool IsUsingData(vtkDataSet *ds)
+		{
+			if(!this->UniformGridVolumeRenderingHelper::IsUsingData(ds)) return false;
+			return this->IsAvailable();
+		}
+
+		virtual bool IsAvailable()
+		{
+			return (mMapper->IsRenderSupported(mParent->GetViewModule()->GetRenderWindow(),mParent->GetVolume()->GetProperty()) != 0);
+		}
+
+	protected:
+
+		virtual void AdjustSpacing()
+		{
+			if(mMapper->GetAutoAdjustSampleDistances() == 0)
+			{
+				mMapper->SetImageSampleDistance(mImageDownsampleFactor);
+			}
+			mMapper->SetSampleDistance(mDepthDownsampleFactor*mDataSpacing);
+		}
+
+	private:
+
+		vtkGPUVolumeRayCastMapper *mMapper;
+	};
+#endif
+
+
 /*
 	class ShearWarpRayCastHelper : public UniformGridVolumeRenderingHelper
 	{
@@ -517,6 +596,10 @@ void iVolumeViewSubject::ConfigureBody()
 
 	m = new Texture2DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 	m = new Texture3DHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
+
+#ifndef IVTK_PRE56
+	m = new GPURayCastHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
+#endif
 #ifdef VTK_USE_VOLUMEPRO
 	m = new VolumeProHelper(this,mDataReplicated->GetOutput()); IERROR_ASSERT(m); mHelpers.Add(m);
 #endif
