@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -34,9 +34,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "icontrolmodule.h"
-#include "ishell.h"
+#include "ierror.h"
 #include "istring.h"
 
+#include "iclinputchannel.h"
+#include "iclshell.h"
+
 #include <vtkIOStream.h>
 
 
@@ -45,6 +48,8 @@ using namespace iParameter;
 
 iclCommandInterpreter::iclCommandInterpreter(iShell *s) : iCommandInterpreter(s)
 {
+	mInputChannel = iRequiredCast<iclShell>(INFO,this->GetShell())->GetInputChannel();
+	mCache.Clear();
 }
 
 
@@ -53,10 +58,16 @@ iclCommandInterpreter::~iclCommandInterpreter()
 }
 
 
+void iclCommandInterpreter::InternalCache::Clear()
+{
+	Text.Clear();
+	Reset = Ready = false;
+}
+
+
 void iclCommandInterpreter::Initialize()
 {
 	this->DislayLineOfText("To execute entered commands, put a semi-colon at the end of the last one.",CommandInterpreterType::Result);
-	this->DislayLineOfText("Type '.' to activate mouse interaction in the visualization window.",CommandInterpreterType::Result);
 }
 
 
@@ -65,25 +76,54 @@ void iclCommandInterpreter::Finalize()
 }
 
 
-void iclCommandInterpreter::DisplayPrompt() const
+void iclCommandInterpreter::RunScript(const iString &text, bool reset)
 {
-	cout << endl;
-	cerr << ": ";
+	mCache.Text = text;
+	mCache.Reset = reset;
+	mCache.Ready = true;
 }
 
 
-void iclCommandInterpreter::ReadLineOfText(iString &line) const
+void iclCommandInterpreter::CommitExec()
 {
-	char c[2];
-	c[1] = 0;
-
-	while(((c[0]=getchar()) != EOF) && (c[0] != '\n'))
+	if(mCache.Ready)
 	{
-		line += c;
+		this->iCommandInterpreter::RunScript(mCache.Text,mCache.Reset);
+		mCache.Clear();
 	}
 }
 
 
+bool iclCommandInterpreter::IsReady()
+{
+	char c[2] = { 0, 0 };
+
+	if(mCache.Ready) return true; // Do nothing until we are executed
+
+	if(mLine.IsEmpty())
+	{
+			//
+			//  Display prompt
+			//
+			cout << endl;
+			cerr << ": ";
+			mLine += " ";
+	}
+
+	while((c[0]=mInputChannel->NextChar()) != 0)
+	{
+		mLine += c;
+		if(c[0] == '\n')
+		{
+			this->Append(mLine);
+			mLine.Clear();
+		}
+	}
+
+	return mCache.Ready;
+}
+
+
 void iclCommandInterpreter::DislayLineOfText(const iString &text, int) const
 {
 	cout << text.ToCharPointer() << endl;
@@ -106,28 +146,8 @@ void iclCommandInterpreter::AnalyseSpecialCommands(const iString &line)
 	//
 	if(line=="exit" || line=="quit")
 	{
-		this->Break(1);
-		return;
+		this->GetShell()->Exit();
 	}
-
-	//
-	//  Are we out for interaction?
-	//
-	if(line=="." || line=="window")
-	{
-		cout << "Use mouse to interact with the visualization window." << endl;
-		cout << "Press 'q' in the visualization window to return to prompt." << endl;
-		this->Break(0);
-		return;
-	}
-}
-
-
-void iclCommandInterpreter::CheckBreak()
-{
-	//
-	//  Do nothing here, we check for break in AnalyseSpecialCommands
-	//
 }
 
 #endif
