@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -33,6 +33,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icommandinterpreter.h"
 
 
+class iclInputChannel;
+
+
 class iclCommandInterpreter : public iCommandInterpreter
 {
 
@@ -40,18 +43,32 @@ public:
 
 	iclCommandInterpreter(iShell *s);
 
+	bool IsReady();
+	void CommitExec();
+
 	virtual void DislayLineOfText(const iString &text, int type) const;
 
 protected:
 
 	virtual ~iclCommandInterpreter();
 
+	virtual void RunScript(const iString &text, bool reset = false);
+
 	virtual void Initialize();
-	virtual void DisplayPrompt() const;
-	virtual void ReadLineOfText(iString &line) const;
 	virtual void AnalyseSpecialCommands(const iString &line);
-	virtual void CheckBreak();
 	virtual void Finalize();
+
+	struct InternalCache
+	{
+		iString Text;
+		bool Reset;
+		bool Ready;
+		void Clear();
+	}
+	mCache;
+
+	iString mLine;
+	iclInputChannel *mInputChannel;
 };
 
 #endif  // ICLCOMMANDINTERPRETER_H
