@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -223,12 +223,6 @@ void iclPickEventObserver::Finished()
 	cout << "(Pick nothing to hide the picked point marker.)" << endl;
 }
 
-//
-//  iclRecordEventObserver class
-//
-void iclRecordEventObserver::UpdateInteraction()
-{
-}
 
 //
 //  iclParallelUpdateEventObserver class
