@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -33,18 +33,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iclcontrolscript.h"
 
 
+#include "icontrolmodule.h"
+#include "ierror.h"
 #include "ihelpfactory.h"
 #include "istring.h"
+#include "isystem.h"
 
-
-#ifndef I_NO_CONSOLE_IO
-#ifdef _WIN32
-#include <conio.h>
-#define getch() _getch()
-#else
-#include <curses.h>
-#endif
-#endif
+#include "iclinputchannel.h"
+#include "iclshell.h"
 
 
 #define curScript	iRequiredCast<iclControlScript>(INFO,me)
@@ -52,6 +48,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iclControlScript::iclControlScript(iControlModule *cm, iScript *parent) : iControlScript(cm,parent)
 {
+	mInputChannel = iRequiredCast<iclShell>(INFO,this->GetControlModule()->GetShell())->GetInputChannel();
 }
 
 
@@ -85,12 +82,8 @@ void iclControlScript::OutputText(const iString &s0) const
 		{
 			cout << "Press <Enter> to continue...";
 			cout.flush();
-#ifndef I_NO_CONSOLE_IO
-			getch();
+			while(mInputChannel->NextChar() != '\n') iSystem::Sleep(100);
 			cout << "\r                            \r";
-#else
-			getchar();
-#endif
 		}
 	}
 }
@@ -109,18 +102,4 @@ void iclControlScript::OutputError(const iString &s0) const
 	cerr << "ERROR: " << s.ToCharPointer() << endl;
 }
 
-
-//
-//  This is whether the actual help text lives
-//
-const iString& iclControlScript::GetHelpString(_HelpId id) const
-{
-	static const iString s0 = iControlScript::GetHelpString(_Root) + 
-		 "<blockquote>"
-		 "    <code><b>window</b></code><br></blockquote>"
-		 "activates mouse interaction in the current visualization window; press <code>q</code> in the visualization window to switch back to shell. You can also use a single dot (.) as a shortcut to this command.<br>";
-
-	if(id == _Root) return s0; else return iControlScript::GetHelpString(id);
-}
-
 #endif
