@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -36,6 +36,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 class iclCommandInterpreter;
+class iclInputChannel;
+
+class vtkRenderWindowInteractor;
 
 
 class iclShell : public iShell
@@ -49,6 +52,8 @@ public:
 
 	virtual void Exit();
 
+	iclInputChannel* GetInputChannel() const { return mInputChannel; }
+
 protected:
 
 	iclShell(int argc, char **argv);
@@ -66,8 +71,10 @@ protected:
 	virtual void DefineSpecificCommandLineOptions();
 	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o);
 
+	int mTimerId;
 	iclCommandInterpreter *mInterpreter;
-	bool mContinue;
+	iclInputChannel *mInputChannel;
+	vtkRenderWindowInteractor *mDriver;
 };
 
 #endif  // ICLSHELL_H
