@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -27,7 +27,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iconfigure.h"
-
+#if ISHELL_INCLUDED(ISHELL_GG)
 
 #include "icontrolmodule.h"
 #include "ierror.h"
@@ -35,11 +35,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "istring.h"
 #include "iviewmodule.h"
 
-#if defined(ISHELL)
-
 #include "iggsubjectfactory.h"
 
-
 #include "iggdialog.h"
 #include "iggextensionwindow.h"
 #include "iggframe.h"
