@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -39,7 +39,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ipicker.h"
 #include "iviewmodule.h"
 
-#include "iggdialogeventrecorder.h"
 #include "iggdialogparallelcontroller.h"
 #include "iggdialogpickerwindow.h"
 #include "iggdialogrenderingprogress.h"
@@ -172,19 +171,6 @@ void iggPickEventObserver::Finished()
 }
 
 
-//
-//  iggRecordEventObserver class
-//
-void iggRecordEventObserver::UpdateInteraction()
-{
-	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetViewModule()->GetControlModule()->GetShell());
-	if(s!=0 && s->GetMainWindow()!=0 && s->GetMainWindow()->GetDialogEventRecorder()!=0) 
-	{
-		s->GetMainWindow()->GetDialogEventRecorder()->UpdateInteraction();
-	}
-}
-
-
 //
 //  iggParallelUpdateEventObserver class
 //
