@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -67,7 +67,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogauto.h"
 #include "iggdialogcommandline.h"
 #include "iggdialogdataexplorer.h"
-#include "iggdialogeventrecorder.h"
 #include "iggdialogfilesetexplorer.h"
 #include "iggdialoghelp.h"
 #include "iggdialogimagecomposer.h"
@@ -171,7 +170,6 @@ namespace iggMainWindow_Private
 			const int ScriptDebugger = 101;
 			const int PaletteEditor = 102;
 			const int PickerWindow = 103;
-			const int EventRecorder = 104;
 			const int ParallelController = 105;
 			const int FileSetExplorer = 106;
 			const int DataExplorer = 107;
@@ -976,7 +974,6 @@ void iggMainWindow::StartInitialization()
 	mDialogCommandLine = new iggDialogCommandLine(this); IERROR_ASSERT(mDialogCommandLine);
 	mDialogDataExplorer = new iggDialogDataExplorer(this); IERROR_ASSERT(mDialogDataExplorer);
 	mDialogDocking = new DialogDocking(this); IERROR_ASSERT(mDialogDocking);
-	mDialogEventRecorder = new iggDialogEventRecorder(this); IERROR_ASSERT(mDialogEventRecorder);
 	mDialogFileSetExplorer = new iggDialogFileSetExplorer(this); IERROR_ASSERT(mDialogFileSetExplorer);
 	mDialogHelp = new iggDialogHelp(this); IERROR_ASSERT(mDialogHelp);
 	mDialogImageComposer = new iggDialogImageComposer(this); IERROR_ASSERT(mDialogImageComposer);
@@ -1111,7 +1108,6 @@ iggMainWindow::~iggMainWindow()
 	if(mDialogCommandLine != 0) delete mDialogCommandLine;
 	if(mDialogDataExplorer != 0) delete mDialogDataExplorer;
 	if(mDialogDocking != 0) delete mDialogDocking;
-	if(mDialogEventRecorder != 0) delete mDialogEventRecorder;
 	if(mDialogFileSetExplorer != 0) delete mDialogFileSetExplorer;
 	if(mDialogHelp != 0) delete mDialogHelp;
 	if(mDialogImageComposer != 0) delete mDialogImageComposer;
@@ -2114,7 +2110,6 @@ void iggMainWindow::BuildMenus()
 		if(mDialogScriptDebugger != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::ScriptDebugger,"&Animation Script Debugger",iImageFactory::FindIcon("debug.png"),"Ctrl+A",false,false);
 		if(mDialogPaletteEditor != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::PaletteEditor,"Palette &Editor",iImageFactory::FindIcon("paled.png"),"Ctrl+E",false,false);
 		if(mDialogPickerWindow != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::PickerWindow,"&Picker Window",iImageFactory::FindIcon("picks.png"),"Ctrl+P",false,false);
-		if(mDialogEventRecorder != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::EventRecorder,"Event &Recorder",iImageFactory::FindIcon("recorder.png"),"Ctrl+R",false,false);
 		if(mDialogFileSetExplorer != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::FileSetExplorer,"&File Set Explorer",iImageFactory::FindIcon("setexp.png"),"Ctrl+F",false,false,&iDataReader::KeyIsSet());
 		mExtensionWindow->PopulateLocalDialogMenu();
 	
@@ -2467,11 +2462,6 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				if(mDialogPickerWindow != 0) mDialogPickerWindow->Show(true);
 				break;
 			}
-		case Menu::Dialog::EventRecorder:
-			{
-				if(mDialogEventRecorder != 0) mDialogEventRecorder->Show(true);
-				break;
-			}
 		case Menu::Dialog::ParallelController:
 			{
 				if(mDialogParallelController != 0) mDialogParallelController->Show(true);
