@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -46,6 +46,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "imarkerfamily.h"
 #include "ipalette.h"
 #include "ipaletteset.h"
+#include "iparallelmanager.h"
 #include "ipointglyph.h"
 #include "irendertool.h"
 #include "ishell.h"
@@ -1533,6 +1534,32 @@ namespace iggPageView_Private
 			}
 		}
 	};
+
+
+	class ParallelExecutionBox : public iggWidgetSimpleRadioBox
+	{
+
+	public:
+
+		ParallelExecutionBox(iggFrame *parent) : iggWidgetSimpleRadioBox(1,"Execution",parent)
+		{
+			this->SetBaloonHelp("Specifiy serial or parallel execution mode","Use this control to quickly switch from a serial (single core) to parallel (multiple cores/processors). More elaborate control of parallel execution id provided by the Parallel Controller dialog.");
+			this->InsertItem("Serial");
+			this->InsertItem("Parallel");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			mSubject->SetValue((this->GetShell()->GetControlModule()->GetParallelManager()->GetNumberOfProcessors()==1)?0:1);
+		}
+
+		virtual void OnInt1Body(int i)
+		{
+			this->GetShell()->GetControlModule()->GetParallelManager()->SetNumberOfProcessors((i==0)?this->GetShell()->GetControlModule()->GetParallelManager()->GetMinNumberOfProcessors():this->GetShell()->GetControlModule()->GetParallelManager()->GetMaxNumberOfProcessors());
+		}
+	};
 };
 
 using namespace iggPageView_Private;
@@ -1570,7 +1597,17 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		iggWidgetKeyCheckBox *pp = new iggWidgetKeyCheckBox("Perspective",iCamera::KeyParallelProjection(),pf);
 		pf->AddLine(pp);
 		pp->SetReverse(true);
-		page0->AddLine(pf);
+
+		if(this->GetShell()->GetControlModule()->GetParallelManager()->GetMaxNumberOfProcessors() > 1)
+		{
+			iggWidget *peb = new ParallelExecutionBox(page0);
+			page0->AddLine(pf,peb);
+		}
+		else
+		{
+			page0->AddLine(pf);
+		}
+
 		page0->AddLine(new iggWidgetKeyExecButton("Reset view",iCamera::KeyReset(),page0),new iggWidgetLaunchButton(mWindowSizeDialog,"Set window size",page0));
 		page0->AddSpace(2);
 
