@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2006 Nick Gnedin 
+Copyright (c) 2002-2011 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -59,7 +59,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 iqtShellSubject::iqtShellSubject(iggShell *owner, int argc, char **argv) : ibgShellSubject(owner,argc,argv)
 {
-	new QApplication(argc,argv);
+	qtargc = argc;
+	qtargv = argv;
+	new QApplication(qtargc,qtargv);
 
 	//
 	//  Test that Qt is compiled with RTTI 
